@@ -25,92 +25,79 @@ class DescribeCheckWarningSummaryRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeCheckWarningSummary')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TargetType(self):
+	def get_TargetType(self): # String
 		return self.get_query_params().get('TargetType')
 
-	def set_TargetType(self,TargetType):
-		self.add_query_param('TargetType',TargetType)
-
-	def get_ContainerFieldName(self):
+	def set_TargetType(self, TargetType):  # String
+		self.add_query_param('TargetType', TargetType)
+	def get_ContainerFieldName(self): # String
 		return self.get_query_params().get('ContainerFieldName')
 
-	def set_ContainerFieldName(self,ContainerFieldName):
-		self.add_query_param('ContainerFieldName',ContainerFieldName)
-
-	def get_RiskName(self):
+	def set_ContainerFieldName(self, ContainerFieldName):  # String
+		self.add_query_param('ContainerFieldName', ContainerFieldName)
+	def get_RiskName(self): # String
 		return self.get_query_params().get('RiskName')
 
-	def set_RiskName(self,RiskName):
-		self.add_query_param('RiskName',RiskName)
-
-	def get_SourceIp(self):
+	def set_RiskName(self, RiskName):  # String
+		self.add_query_param('RiskName', RiskName)
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_ContainerFieldValue(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_ContainerFieldValue(self): # String
 		return self.get_query_params().get('ContainerFieldValue')
 
-	def set_ContainerFieldValue(self,ContainerFieldValue):
-		self.add_query_param('ContainerFieldValue',ContainerFieldValue)
-
-	def get_PageSize(self):
+	def set_ContainerFieldValue(self, ContainerFieldValue):  # String
+		self.add_query_param('ContainerFieldValue', ContainerFieldValue)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Lang(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_CurrentPage(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_ClusterId(self):
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_RiskStatus(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_RiskStatus(self): # Integer
 		return self.get_query_params().get('RiskStatus')
 
-	def set_RiskStatus(self,RiskStatus):
-		self.add_query_param('RiskStatus',RiskStatus)
-
-	def get_StrategyId(self):
+	def set_RiskStatus(self, RiskStatus):  # Integer
+		self.add_query_param('RiskStatus', RiskStatus)
+	def get_StrategyId(self): # Long
 		return self.get_query_params().get('StrategyId')
 
-	def set_StrategyId(self,StrategyId):
-		self.add_query_param('StrategyId',StrategyId)
-
-	def get_TypeName(self):
+	def set_StrategyId(self, StrategyId):  # Long
+		self.add_query_param('StrategyId', StrategyId)
+	def get_TypeName(self): # String
 		return self.get_query_params().get('TypeName')
 
-	def set_TypeName(self,TypeName):
-		self.add_query_param('TypeName',TypeName)
-
-	def get_Status(self):
+	def set_TypeName(self, TypeName):  # String
+		self.add_query_param('TypeName', TypeName)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
-
-	def get_Uuids(self):
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
+	def get_Uuids(self): # String
 		return self.get_query_params().get('Uuids')
 
-	def set_Uuids(self,Uuids):
-		self.add_query_param('Uuids',Uuids)
\ No newline at end of file
+	def set_Uuids(self, Uuids):  # String
+		self.add_query_param('Uuids', Uuids)
